Thanks for taking the time for reporting an issue!

Before reporting an issue on dd-trace-py, please be sure to provide all
necessary information.

If you're hitting a bug, make sure that you're using the latest version of this
library.

### Which version of dd-trace-py are you using?

### Which version of pip are you using?

_ddtrace requires pip>=18 to install one of our pre-built wheels_

### Which version of the libraries are you using?

You can copy/paste the output of `pip freeze` here.

### How can we reproduce your problem?

### What is the result that you get?

### What is the result that you expected?
